@@ -23,7 +23,7 @@ from . import s_log , s_db
 
 def cleanup( ) :
     #pass
-    s_db.fdelete( )
+    s_db.filepath_delete_all( )
     #s_log.write( "cleanup" )
 
 #####################################################################
